summaryrefslogtreecommitdiffstats
path: root/src/simulator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/simulator.cpp')
-rw-r--r--src/simulator.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/simulator.cpp b/src/simulator.cpp
index c0f406d..bc6ab55 100644
--- a/src/simulator.cpp
+++ b/src/simulator.cpp
@@ -15,7 +15,7 @@
#include "switch.h"
#include <kstaticdeleter.h>
-#include <qtimer.h>
+#include <tqtimer.h>
//BEGIN class Simulator
@@ -56,8 +56,8 @@ Simulator::Simulator()
m_pChangedCircuitStart = new Circuit;
m_pChangedCircuitLast = m_pChangedCircuitStart;
- QTimer * stepTimer = new QTimer(this);
- connect( stepTimer, SIGNAL(timeout()), this, SLOT(step()) );
+ TQTimer * stepTimer = new TQTimer(this);
+ connect( stepTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(step()) );
stepTimer->start(1);
}
@@ -80,7 +80,7 @@ void Simulator::step()
if (!m_bIsSimulating)
return;
// We are called a thousand times a second (the maximum allowed by QTimer),
// so divide the LINEAR_UPDATE_RATE by 1e3 for the number of loops we need
// to do.
const unsigned maxSteps = unsigned(LINEAR_UPDATE_RATE/1e3);
@@ -247,7 +247,7 @@ void Simulator::createLogicChain( LogicOut * logicOut, const LogicInList & logic
addChangedLogic(logicOut);
logicOut->setCanAddChanged(false);
- if ( !m_logicChainStarts.contains( logicOut ) )
+ if ( !m_logicChainStarts.tqcontains( logicOut ) )
m_logicChainStarts << logicOut;
}
@@ -383,8 +383,8 @@ void Simulator::removeLogicInReferences( LogicIn * logicIn )
if ( !logicIn )
return;
- QValueList<LogicOut*>::iterator end = m_logicChainStarts.end();
- for ( QValueList<LogicOut*>::iterator it = m_logicChainStarts.begin(); it != end; ++it )
+ TQValueList<LogicOut*>::iterator end = m_logicChainStarts.end();
+ for ( TQValueList<LogicOut*>::iterator it = m_logicChainStarts.begin(); it != end; ++it )
{
LogicIn * logicCallback = *it;
while (logicCallback)
@@ -80,7 +80,7 @@ void Simulator::step()
if (!m_bIsSimulating)
return;
- // We are called a thousand times a second (the maximum allowed by QTimer),
+ // We are called a thousand times a second (the maximum allowed by TQTimer),
// so divide the LINEAR_UPDATE_RATE by 1e3 for the number of loops we need
// to do.